SystemOrganization addCategory: #'FSExtensions-Collections'!

!FSUnixResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 16:02'!
sysProgramFiles
	" Answer a String referencing the program files directory in the receiver's system "
	
	^ '/usr/local/bin'! !

!FSUnixResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 16:02'!
trimPath: aCollection
	" Private - OS differ in the output of their variables, e.g. Windows adds the PATH variable name
	as first string and a carriage return in the last path "

	^ aCollection findTokens: ';='! !

OrderedCollection subclass: #FSReferenceCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FSExtensions-Collections'!

!FSReferenceCollection commentStamp: 'hfm 2/2/2011 20:02' prior: 0!
FSReferenceCollection resolves references just one level of deepness. It is appropiate when you have a collection of references for which you know you're searching only in those references and not in subtrees. An example of use is the output of the system PATH variable.
!

!FSReferenceCollection methodsFor: 'resolving' stamp: 'hfm 2/2/2011 21:03'!
resolve: anObject
	" Same as locator #resolve but acting on a collection "
	
	| path findString |
	
	findString := anObject basename trimBoth asLowercase.
	path := self 
			detect: [: fsRef | fsRef children includes: ( fsRef resolveString: findString ) ]
			ifNone: [ self error: anObject asString , ' not found' ].
	^ path / anObject basename! !

OrderedCollection subclass: #FSReferenceTree
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FSExtensions-Collections'!

!FSReferenceTree commentStamp: 'hfm 2/2/2011 20:03' prior: 0!
FSReferenceTree resolves references by traversing all the collection at all levels and detecting the searched reference. It is appropiate when you have a collection of references for which you don't know where the element could be found.
!

!FSReferenceTree methodsFor: 'resolving' stamp: 'hfm 2/2/2011 20:27'!
resolve: anObject
	" Same as locator #resolve but acting on a collection "

	| path findString |

	findString := anObject asReference basename.
	self do: [: fsRef 	| 
			| found |
			( found := fsRef resolveFilename: findString ) 
				ifNotNil: [ ^ found reference asString ] ].
	^ nil
! !

!FSLocator class methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 12:38'!
sysEnvBinaries
	" Answer the receiver at origin specified by resolver's binaries path.
	This is for binaries accessible for the system environment, usually
	found in PATH variable in the guest operating system "

	^ self origin: #sysEnvBinaries! !

!FSLocator class methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 16:11'!
userBinaries
	" Answer the receiver at origin specified by resolver's binaries path.
	This is for binaries accessible in the 'program files' directory in the guest operating system "
	
	^ self origin: #userBinaries! !

!FSWindowsResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:09'!
sysProgramFiles
	" Answer a String referencing the program files directory in the receiver's system "

	^ self trimEcho: ( ProcessWrapper new
			useStdout;
			startWithShellCommand: 'echo %programfiles%';
			upToEnd )! !

!FSWindowsResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:19'!
trimPath: aCollection
	" Private - OS differ in the output of their variables, e.g. Windows adds the PATH variable name
	as first string and a carriage return in the last path "
	
	| newCollection |
	
	( newCollection := aCollection findTokens: ';=' ) ifNotEmpty: [ 
		" Remove the variable name "
		newCollection removeFirst.
		" Remove the additional carriage return "		
		newCollection
			ifNotEmpty: [ 
				| trimmed |
				trimmed := newCollection last trimRight.
				newCollection removeLast.
				newCollection addLast: trimmed ] ].
	^ newCollection! !

!FSSystemResolver methodsFor: '*fsextensions' stamp: 'hfm 1/29/2011 18:23'!
resolveCollection: aCollection

	^ aCollection collect: [: each | self resolveString: each ]! !

!FSSystemResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 15:37'!
supportedOrigins
	^ #(image vmBinary vmDirectory userBinaries sysEnvBinaries)! !

!FSSystemResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:06'!
sysEnvBinaries
	" Answer a Collection with all system path where binaries are searched "
	
	^ ( self resolveCollection: self sysEnvBinariesPath ) asReferenceCollection! !

!FSSystemResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 15:56'!
sysEnvBinariesPath
	" Answer a Collection including all system path for binaries
	taken from the system's PATH variable "
	
	| process paths |
	process := ProcessWrapper new.
	paths := process 
				useStdout;
				startWithShellCommand: 'PATH';
				upToEnd.
	^ self next trimPath: paths! !

!FSSystemResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:06'!
userBinaries
	" Answer a Collection with the path where user binaries are searched "
	
	^ ( self resolveCollection: self userBinariesPath ) asReferenceTree! !

!FSSystemResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:07'!
userBinariesPath
	" Answer a Collection including all system path for user binaries "
	
	^ OrderedCollection with: self next sysProgramFiles! !

!FSReference methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:38'!
resolveFilename: aString

	| findString |
	
	findString := aString trimBoth asLowercase.
	^ self allEntries 
			detect: [ : ref | ref basename asLowercase = findString ]
			ifOne: [ : found | found ]! !

!FSMacOSResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 16:05'!
trimPath: aCollection
	" Private - OS differ in the output of their variables, e.g. Windows adds the PATH variable name
	as first string and a carriage return in the last path "

	self needsWork.
	" Find out how MacOS tokenize environment variables "
	^ aCollection findTokens: '?'! !

!FSPlatformResolver methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 16:04'!
trimEcho: aString
	" Private - OS differ in the output of their variables, e.g. echo command
	adds an extra separator at the end of output "
	
	^ aString trimRight
! !

!Collection methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:01'!
asReferenceCollection
	" See the comment in FSReferenceCollection "
	
	^ FSReferenceCollection withAll: self! !

!Collection methodsFor: '*fsextensions' stamp: 'hfm 2/2/2011 20:02'!
asReferenceTree
	" See the comment in FSReferenceTree "
	
	^ FSReferenceTree withAll: self! !
